from  distutils.core import setup
# with open('README.md', 'r') as fh:
#     long_description = fh.read()
setup(
    name = 'wcommon',
    version = '1.0.0',
    author = 'WangJunbo',
    author_mail = '1257680563@qq.com',
    description = '第一次提交',
    # long_description = long_description,
    # long_description_content_type = "text/markdown",
    # packages=["wcommon"]
)